OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "L'emmagatzematge no està disponible temporalment",
    "Storage invalid" : "L'emmagatzematge no és vàlid",
    "Unknown error" : "Error desconegut",
    "File could not be found" : "No s'ha pogut trobar el fitxer",
    "Move or copy" : "Mou o copia",
    "Download" : "Baixa",
    "Delete" : "Suprimeix",
    "Home" : "Inici",
    "Close" : "Tanca",
    "Favorites" : "Preferits",
    "Could not create folder \"{dir}\"" : "No s'ha pogut crear la carpeta «{dir}»",
    "This will stop your current uploads." : "Això aturarà les pujades actuals.",
    "Upload cancelled." : "S'ha cancel·lat la pujada.",
    "Processing files …" : "S'estan processant els fitxers...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No s'ha pogut pujar {filename} perquè és una carpeta o té 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hi ha prou espai lliure, esteu pujant {size1} però només teniu {size2} lliures",
    "Target folder \"{dir}\" does not exist any more" : "La carpeta de destinació «{dir}» ja no existeix",
    "Not enough free space" : "No hi ha prou espai lliure",
    "An unknown error has occurred" : "S'ha produït un error desconegut",
    "Uploading …" : "S'està pujant...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "No s'admet la pujada aquest element",
    "Target folder does not exist any more" : "La carpeta de destinació ja no existeix",
    "Operation is blocked by access control" : "L'operació està blocada pel control d'accés",
    "Error when assembling chunks, status code {status}" : "S'ha produït un error en recopilar els fragments, el codi d'estat és {status}",
    "Actions" : "Accions",
    "Rename" : "Canvia el nom",
    "Move" : "Mou",
    "Copy" : "Copia",
    "Choose target folder" : "Trieu la carpeta de destinació",
    "Open" : "Obre",
    "Delete file" : "Suprimeix el fitxer",
    "Delete folder" : "Suprimeix la carpeta",
    "Disconnect storage" : "Desconnecta l'emmagatzematge",
    "Leave this share" : "Abandona aquest element compartit",
    "Could not load info for file \"{file}\"" : "No s'ha pogut carregar la informació del fitxer «{file}»",
    "Files" : "Fitxers",
    "Details" : "Detalls",
    "Show list view" : "Mostra en vista de llista",
    "Show grid view" : "Mostra en vista de graella",
    "Please select tag(s) to add to the selection" : "Seleccioneu les etiquetes que voleu afegir a la selecció",
    "Apply tag(s) to selection" : "Aplica les etiquetes a la selecció",
    "Select directory \"{dirName}\"" : "Selecciona la carpeta «{dirName}»",
    "Select file \"{fileName}\"" : "Selecciona el fitxer «{fileName}»",
    "Pending" : "Pendent",
    "Unable to determine date" : "No s'ha pogut determinar la data",
    "This operation is forbidden" : "Aquesta operació no està permesa",
    "This directory is unavailable, please check the logs or contact the administrator" : "Aquesta carpeta no està disponible. Consulteu els registres o poseu-vos en contacte amb l'administrador.",
    "Could not move \"{file}\", target exists" : "No s'ha pogut desplaçar «{file}», el fitxer de destinació ja existeix",
    "Could not move \"{file}\"" : "No s'ha pogut desplaçar «{file}»",
    "copy" : "còpia",
    "Could not copy \"{file}\", target exists" : "No s'ha pogut copiar «{file}», el fitxer de destinació ja existeix",
    "Could not copy \"{file}\"" : "No s'ha pogut copiar «{file}»",
    "Copied {origin} inside {destination}" : "S'ha copiat {origin} a {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "S'han copiat {origin} i {nbfiles} fitxers més a {destination}",
    "{newName} already exists" : "{newName} ja existeix",
    "Could not rename \"{fileName}\", it does not exist any more" : "No s'ha pogut canviar el nom de «{fileName}», ja no existeix",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nom «{targetName}» ja està en ús en la carpeta «{dir}». Trieu un nom diferent.",
    "Could not rename \"{fileName}\"" : "No s'ha pogut canviar el nom de «{fileName}»",
    "Could not create file \"{file}\"" : "No s'ha pogut crear el fitxer «{file}»",
    "Could not create file \"{file}\" because it already exists" : "No s'ha pogut crear el fitxer «{file}» perquè ja existeix",
    "Could not create folder \"{dir}\" because it already exists" : "No s'ha pogut crear la carpeta «{dir}» perquè ja existeix",
    "Could not fetch file details \"{file}\"" : "No s'han pogut recuperar els detalls del fitxer «{file}»",
    "Error deleting file \"{fileName}\"." : "S'ha produït un error en suprimir el fitxer «{fileName}».",
    "No search results in other folders for {tag}{filter}{endtag}" : "No hi ha cap resultat de cerca en altres carpetes per a {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Introduïu més de dos caràcters per a cercar en altres carpetes",
    "Name" : "Nom",
    "Size" : "Mida",
    "Modified" : "Darrera modificació",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "_%n file_::_%n files_" : ["%n fitxer","%n fitxers"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "_including %n hidden_::_including %n hidden_" : ["incloent-hi %n element ocult","incloent-hi %n elements ocults"],
    "You do not have permission to upload or create files here" : "No teniu permís per a pujar o crear fitxers aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["S'està pujant %n fitxer","S'estan pujant %n fitxers"],
    "Select file range" : "Selecciona un interval de fitxers",
    "{used} of {quota} used" : "{used} de {quota} en ús",
    "{used} used" : "{used} en ús",
    "\"{name}\" is an invalid file name." : "«{name}» no és un nom de fitxer vàlid.",
    "File name cannot be empty." : "El nom del fitxer no pot estar buit.",
    "\"/\" is not allowed inside a file name." : "No es permet l'ús del caràcter «/» en el nom d'un fitxer.",
    "\"{name}\" is not an allowed filetype" : "«{name}» no és un tipus de fitxer permès",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "L'emmagatzematge de l'usuari {owner} està ple, els fitxers ja no es poden actualitzar ni sincronitzar!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La carpeta de grup «{mountPoint}» està plena, els fitxers ja no es poden actualitzar ni sincronitzar!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "L'emmagatzematge extern «{mountPoint}» està ple, els fitxers ja no es poden actualitzar ni sincronitzar!",
    "Your storage is full, files cannot be updated or synced anymore!" : "L'emmagatzematge està ple, els fitxers ja no es poden actualitzar ni sincronitzar!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "L'emmagatzematge de {owner} està gairebé ple ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La carpeta de grup «{mountPoint}» està gairebé plena ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'emmagatzematge extern «{mountPoint}» està gairebé ple ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "L'emmagatzematge està gairebé ple ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincideix amb «{filter}»","coincideixen amb «{filter}»"],
    "View in folder" : "Visualitza-ho a la carpeta",
    "Copied!" : "S'ha copiat!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copia l'enllaç directe (només funciona per als usuaris que tinguin accés a aquest fitxer o carpeta)",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "S'ha afegit als preferits",
    "Favorite" : "Preferits",
    "You can only favorite a single file or folder at a time" : "Només podeu afegir als preferits un fitxer o carpeta alhora",
    "New folder" : "Crea una carpeta",
    "Upload file" : "Puja un fitxer",
    "Recent" : "Recents",
    "Not favorited" : "S'ha suprimit dels preferits",
    "Remove from favorites" : "Suprimeix dels preferits",
    "Add to favorites" : "Afegeix als preferits",
    "An error occurred while trying to update the tags" : "S'ha produït un error en intentar actualitzar les etiquetes",
    "Added to favorites" : "S'ha afegit als preferits",
    "Removed from favorites" : "S'ha suprimit dels preferits",
    "You added {file} to your favorites" : "Heu afegit {file} als preferits",
    "You removed {file} from your favorites" : "Heu suprimit {file} dels preferits",
    "File changes" : "Canvis al fitxer",
    "Created by {user}" : "Creat per {user}",
    "Changed by {user}" : "Modificat per {user}",
    "Deleted by {user}" : "Suprimit per {user}",
    "Restored by {user}" : "Restaurat per {user}",
    "Renamed by {user}" : "Canvi de nom per {user}",
    "Moved by {user}" : "Desplaçat per {user}",
    "\"remote user\"" : "«usuari remot»",
    "You created {file}" : "Heu creat {file}",
    "You created an encrypted file in {file}" : "Heu creat un fitxer xifrat a {file}",
    "{user} created {file}" : "{user} ha creat {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creat un fitxer xifrat a {file}",
    "{file} was created in a public folder" : "S'ha creat {file} en una carpeta pública",
    "You changed {file}" : "Heu modificat {file}",
    "You changed an encrypted file in {file}" : "Heu modificat un fitxer xifrat a {file}",
    "{user} changed {file}" : "{user} ha modificat {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha modificat un fitxer xifrat a {file}",
    "You deleted {file}" : "Heu suprimit {file}",
    "You deleted an encrypted file in {file}" : "Heu suprimit un fitxer xifrat a {file}",
    "{user} deleted {file}" : "{user} ha suprimit {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha suprimit un fitxer xifrat a {file}",
    "You restored {file}" : "Heu restaurat {file}",
    "{user} restored {file}" : "{user} ha restaurat {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Heu canviat el nom de {oldfile} (ocult) a {newfile} (ocult)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Heu canviat el nom de {oldfile} (ocult) a {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Heu canviat el nom de {oldfile} a {newfile} (ocult)",
    "You renamed {oldfile} to {newfile}" : "Heu canviat el nom de {oldfile} a {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} ha canviat el nom de {oldfile} (ocult) a {newfile} (ocult)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} ha canviat el nom de {oldfile} (ocult) a {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} ha canviat el nom de {oldfile} a {newfile} (ocult)",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha canviat el nom de {oldfile} a {newfile}",
    "You moved {oldfile} to {newfile}" : "Heu desplaçat {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} ha desplaçat {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "S'ha afegit o suprimit un fitxer dels <strong>preferits</strong>",
    "A file or folder has been <strong>changed</strong>" : "S'ha <strong>modificat</strong> un fitxer o carpeta",
    "A favorite file or folder has been <strong>changed</strong>" : "S'ha <strong>modificat</strong> un fitxer o carpeta dels preferits",
    "All files" : "Tots els fitxers",
    "Unlimited" : "Il·limitat",
    "Upload (max. %s)" : "Puja (màx. %s)",
    "Accept" : "Accepta",
    "Reject" : "Rebutja",
    "Incoming ownership transfer from {user}" : "{user} us ha enviat una transferència de propietat",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Voleu acceptar {path}?\n\nNota: el procés de transferència després de l'acceptació pot durar fins a 1 hora.",
    "Ownership transfer failed" : "S'ha produït un error en transferir la propietat",
    "Your ownership transfer of {path} to {user} failed." : "S'ha produït un error en transferir la propietat de {path} a {user}.",
    "The ownership transfer of {path} from {user} failed." : "S'ha produït un error en transferir la propietat de {path} de {user}.",
    "Ownership transfer done" : "La transferència de la propietat ha finalitzat",
    "Your ownership transfer of {path} to {user} has completed." : "S'ha completat la transferència de propietat de {path} a {user}.",
    "The ownership transfer of {path} from {user} has completed." : "S'ha completat la transferència de propietat de {path} de {user}.",
    "in %s" : "%s",
    "File Management" : "Gestió de fitxers",
    "Transfer ownership of a file or folder" : "Transferiu la propietat d'un fitxer o carpeta",
    "Choose file or folder to transfer" : "Tria el fitxer o carpeta que s'ha de transferir",
    "Change" : "Canvia",
    "New owner" : "Propietari nou",
    "Search users" : "Cerqueu usuaris",
    "Choose a file or folder to transfer" : "Trieu el fitxer o carpeta que vulgueu transferir",
    "Transfer" : "Transfereix",
    "Transfer {path} to {userid}" : "Transfereix {path} a {userid}",
    "Invalid path selected" : "El camí seleccionat no és vàlid",
    "Ownership transfer request sent" : "S'ha enviat la sol·licitud de transferència de propietat",
    "Cannot transfer ownership of a file or folder you do not own" : "No es pot transferir la propietat d'un fitxer o carpeta que no és vostre",
    "Tags" : "Etiquetes",
    "Unable to change the favourite state of the file" : "No s'ha pogut canviar l'estat de preferit del fitxer",
    "Error while loading the file data" : "S'ha produït un error en carregar la informació del fitxer",
    "Pick a template for {name}" : "Trieu una plantilla per a {name}",
    "Cancel" : "Cancel·la",
    "Create" : "Crea",
    "Create a new file with the selected template" : "Crea un fitxer amb la plantilla seleccionada",
    "Creating file" : "S'està creant el fitxer",
    "Blank" : "En blanc",
    "Unable to create new file from template" : "No s'ha pogut crear el fitxer a partir de la plantilla",
    "Set up templates folder" : "Configura la carpeta de plantilles",
    "Templates" : "Plantilles",
    "Unable to initialize the templates directory" : "No s'ha pogut inicialitzar la carpeta de plantilles",
    "%s used" : "%s en ús",
    "%1$s of %2$s used" : "%1$s de %2$s en ús",
    "Show hidden files" : "Mostra els fitxers ocults",
    "Crop image previews" : "Retalla les previsualitzacions de les imatges",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Utilitzeu aquesta adreça per a accedir als vostres fitxers mitjançant WebDAV",
    "Toggle %1$s sublist" : "Commuta la subllista de %1$s",
    "Toggle grid view" : "Canvia la vista de quadrícula",
    "No files in here" : "No hi ha fitxers aquí",
    "Upload some content or sync with your devices!" : "Pugeu contingut o sincronitzeu els vostres dispositius!",
    "No entries found in this folder" : "No s'ha trobat cap entrada en aquesta carpeta",
    "Select all" : "Selecciona-ho tot",
    "Upload too large" : "La pujada és massa gran",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Els fitxers que intenteu pujar superen la mida màxima de pujada de fitxers del servidor.",
    "No favorites yet" : "Encara no teniu preferits",
    "Files and folders you mark as favorite will show up here" : "Aquí apareixeran els fitxers i carpetes que marqueu com a preferits",
    "Deleted files" : "Fitxers suprimits",
    "Shares" : "Elements compartits",
    "Shared with others" : "Compartit amb altres usuaris",
    "Shared with you" : "Compartit amb vós",
    "Shared by link" : "Compartit amb un enllaç",
    "Deleted shares" : "Suprimit",
    "Pending shares" : "Pendent",
    "Text file" : "Fitxer de text",
    "New text file.txt" : "Fitxer de text nou.txt",
    "Select" : "Selecciona",
    "You don’t have permission to upload or create files here" : "No teniu permís per a pujar o crear fitxers aquí",
    "New" : "Nou",
    "Cannot transfer ownership of a file or folder you don't own" : "No es pot transferir la propietat d'un fitxer o carpeta que no és vostre",
    "%s%% of %s used" : "%s%% de %s en ús",
    "Settings" : "Paràmetres"
},
"nplurals=2; plural=(n != 1);");
